# TODO: Add comment
# 
# Author: Judith Zaugg
###############################################################################

makeHTMLreport=function(projectfolder,overwrite=TRUE){
	require(Biobase)
	outdir=paste(projectfolder,'html',sep='/')
	createFolderIfNotExist(outdir)
	createFolderIfNotExist(paste(outdir,'plots',sep='/'))
	
	createFolderIfNotExist(outdir)
	# get the image files
	plotfiles=dir(paste(projectfolder,'plots',sep='/'))
	plotfilelocations=paste('plots/',plotfiles,sep='')
	# copy the image files to the plot folder in the html folder
	file.copy(paste(projectfolder,'plots/',plotfiles,sep='/'), paste(outdir,'plots/',sep='/'),
			overwrite=overwrite)
	
	titles=sapply(strsplit(plotfiles,'\\.'),'[[',1)
	titles=gsub('.pdf','',gsub('SingleProperty','',gsub('.png','',plotfiles)))
	descriptions=getDescriptions(plotfiles)
	htmlsource=system.file("htmlsrc", "@i@.html", package="AnalyzeGenomicPipeline")
	htmlindex=system.file("htmlsrc", "index.html", package="AnalyzeGenomicPipeline")
	for(i in 1:length(plotfilelocations)){	
		#plotfile = sprintf("%d.%s", i, device)
		sym = list(
				"title"    = titles[i],
				"i"        = paste(i), 
				"previous" = titles[max(i-1L, 1L)],
				"next"     = titles[min(i+1L, length(plotfilelocations))],
				"description" = descriptions[i],
				"image" = paste("<img src=\"",
						plotfilelocations[i],  "\"></img>")
		)
		copySubstitute(src = htmlsource,
				dest = file.path(outdir, sprintf("%s.html", titles[i])),
				symbolValues = sym)
		
	}
	sym = list(
			title = basename(outdir),
			tableofcontents = paste(
					sprintf("<a href=\"%s.html\">%s: %s</a><br>",
							titles,descriptions,titles), collapse="\n"))
	
	res = file.path(outdir, "index.html")
	copySubstitute(src = htmlindex,
			dest = res, symbolValues = sym)
	
	file.copy(system.file("htmlsrc", "AnalyzeGenomicPipeline.css", package="AnalyzeGenomicPipeline"), outdir)
	file.copy(dir(system.file("icons", package="AnalyzeGenomicPipeline"), full.names=TRUE), outdir)
	
}

getDescriptions=function(plotfiles){
	descriptions=plotfiles
	descriptions[grep('TF_heatmap',plotfiles)]='Enrichment of sequence specific TFs in particular clusters'
	descriptions[grep('properties',plotfiles)]='Overview of behaviour of all properties across the different clusters'
	descriptions[grep('SingleProperty',plotfiles)]=
			paste('Analysis of',
					sapply(strsplit(gsub('.png','',gsub('SingleProperty','',descriptions[grep('SingleProperty',plotfiles)])),'\\.'),
							paste,collapse=' '
					)
			)
descriptions[grep('profiles',plotfiles)]='Profiles of each factor in each cluster'
descriptions[grep('^heatmap',plotfiles)]='Heatmap of the clusters'
return(descriptions)	
}
